# ERODE-CoLoMoTo

Python interface to ERODE for Backward Boolean Equivalence reduction of synchronous Boolean networks.

## Installation

### Pip

```
pip install erode-python
```

### Conda

```
conda install -c conda-forge -c colomoto erode-python
```
